seed-papertrail
=============================

.. image:: https://img.shields.io/travis/praekeltfoundation/seed-papertrail.svg
        :target: https://travis-ci.org/praekeltfoundation/seed-papertrail

.. image:: https://img.shields.io/pypi/v/seed-papertrail.svg
        :target: https://pypi.python.org/pypi/seed-papertrail

.. image:: https://coveralls.io/repos/praekeltfoundation/seed-papertrail/badge.png?branch=develop
    :target: https://coveralls.io/r/praekeltfoundation/seed-papertrail?branch=develop
    :alt: Code Coverage

.. image:: https://readthedocs.org/projects/seed-papertrail/badge/?version=latest
    :target: https://seed-papertrail.readthedocs.org
    :alt: seed-papertrail Docs
